@@ -123,12 +123,13 @@ class CloudPods:
             return None
 
     @enter_and_leave_function
-    def create_server_by_guest_image(self,guest_image_id,disk_image_id,arch, disk_size, disks, nets, vm_name, sku,count=1,reset_new_password=""):
+    def create_server_by_guest_image(self,guest_image_id,disk_image_id,arch, disk_size, disks, nets_list, vm_name, sku,count=1,reset_new_password=""):
         if arch == "x86_64":
             bios="BIOS"
         else:
             bios="UEFI"
-        for net in nets:
+        nets=[]
+        for net in nets_list:
             nets.append({"network": net})
         server = {
             "auto_start": True,
